CustomerManagedEncryptionStatus class final

Describes the status of customer-managed encryption.

Constructors

CustomerManagedEncryptionStatus({required String kmsKeyVersionName})
CustomerManagedEncryptionStatus.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyVersionName → String
Required. The resource name of the Cloud KMS CryptoKeyVersion used to encrypt the secret payload, in the following format: projects/*/locations/*/keyRings/*/cryptoKeys/*/versions/*.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String