DeleteSecretRequest class final

Request message for SecretManagerService.DeleteSecret.

Constructors

DeleteSecretRequest({required String name, String etag = ''})
DeleteSecretRequest.fromJson(Object? j)
factory

Properties

etag → String
Optional. Etag of the Secret. The request succeeds if it matches the etag of the currently stored secret object. If the etag is omitted, the request succeeds.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Required. The resource name of the Secret to delete in the format projects/*/secrets/*.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String