ListSecretsRequest class final

Request message for SecretManagerService.ListSecrets.

Constructors

ListSecretsRequest({required String parent, int pageSize = 0, String pageToken = '', String filter = ''})
ListSecretsRequest.fromJson(Object? j)
factory

Properties

filter → String
Optional. Filter string, adhering to the rules in List-operation filtering. List only secrets matching the filter. If filter is empty, all secrets are listed.
final
hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
Optional. The maximum number of results to be returned in a single page. If set to 0, the server decides the number of results to return. If the number is greater than 25000, it is capped at 25000.
final
pageToken → String
Optional. Pagination token, returned earlier via ListSecretsResponse.next_page_token.
final
parent → String
Required. The resource name of the project associated with the Secrets, in the format projects/* or projects/*/locations/*
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String