Replication class final

A policy that defines the replication and encryption configuration of data.

Constructors

Replication({Replication_Automatic? automatic, Replication_UserManaged? userManaged})
Replication.fromJson(Object? j)
factory

Properties

automatic → Replication_Automatic?
The Secret will automatically be replicated without any restrictions.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userManaged → Replication_UserManaged?
The Secret will only be replicated into the locations specified.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String