ReplicationStatus class final

The replication status of a SecretVersion.

Properties

automatic → ReplicationStatus_AutomaticStatus?
Describes the replication status of a SecretVersion with automatic replication.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userManaged → ReplicationStatus_UserManagedStatus?
Describes the replication status of a SecretVersion with user-managed replication.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String