Replication_UserManaged_Replica class final
Represents a Replica for this
Secret.
- Inheritance
-
- Object
- ProtoMessage
- Replication_UserManaged_Replica
Constructors
- Replication_UserManaged_Replica({String location = '', CustomerManagedEncryption? customerManagedEncryption})
- Replication_UserManaged_Replica.fromJson(Object? j)
-
factory
Properties
- customerManagedEncryption → CustomerManagedEncryption?
-
Optional. The customer-managed encryption configuration of the
Replication.UserManaged.Replica. If no configuration is provided, Google-managed default encryption is used.final - hashCode → int
-
The hash code for this object.
no setterinherited
- location → String
-
The canonical IDs of the location to replicate data.
For example:
"us-east1".final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String