Rotation class final
The rotation time and period for a
Secret. At next_rotation_time, Secret
Manager will send a Pub/Sub notification to the topics configured on the
Secret. Secret.topics must be
set to configure rotation.
Constructors
- Rotation({Timestamp? nextRotationTime, Duration? rotationPeriod, Rotation_ManagedRotationStatus? managedRotationStatus})
- Rotation.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- managedRotationStatus → Rotation_ManagedRotationStatus?
-
Output only. The current status of the managed rotation.
This field is only applicable to Typed Secrets.
This field is set by the service and cannot be set by the user.
final
- nextRotationTime → Timestamp?
-
Optional. Timestamp in UTC at which the
Secretis scheduled to rotate. Cannot be set to less than 300s (5 min) in the future and at most 3153600000s (100 years).final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rotationPeriod → Duration?
-
Input only. The Duration between rotation notifications. Must be in seconds
and at least 3600s (1h) and at most 3153600000s (100 years).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String