Rotation_ManagedRotationStatus class final

Represents the status of a managed rotation.

This is applicable only to Typed Secrets. It indicates whether the rotation is active and any errors that may have occurred during the asynchronous managed rotation.

Constructors

Rotation_ManagedRotationStatus({Rotation_ManagedRotationStatus_State state = Rotation_ManagedRotationStatus_State.$default, Status? error})
Rotation_ManagedRotationStatus.fromJson(Object? j)
factory

Properties

error → Status?
Output only. Displays customer-facing issues that occurred during an asynchronous managed rotation. For example, if there are some permission errors.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Rotation_ManagedRotationStatus_State
Output only. Indicates whether the Managed Rotation is active or not.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String