state property
Output only. Indicates whether the Managed Rotation is active or not.
Implementation
final Rotation_ManagedRotationStatus_State state;
Output only. Indicates whether the Managed Rotation is active or not.
final Rotation_ManagedRotationStatus_State state;