Rotation_ManagedRotationStatus_State class final

This defines the various states in which the managed rotation can be.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const Rotation_ManagedRotationStatus_State
The default value for Rotation_ManagedRotationStatus_State.
active → const Rotation_ManagedRotationStatus_State
Indicates that the Managed rotation is ACTIVE.
inactive → const Rotation_ManagedRotationStatus_State
Indicates that the Managed rotation is INACTIVE.
stateUnspecified → const Rotation_ManagedRotationStatus_State
Not specified. This value is unused and invalid.