policyMember property

ResourcePolicyMember? policyMember
final

Output only. Defines the policy member for the secret. This will be used to check if the caller has the permission to perform certain operations on the typed secret.

Implementation

final ResourcePolicyMember? policyMember;