topics property

List<Topic> topics
final

Optional. A list of up to 10 Pub/Sub topics to which messages are published when control plane operations are called on the secret or its versions.

Implementation

final List<Topic> topics;