enableManagedRotation method

Future<SecretVersion> enableManagedRotation(
  1. EnableManagedRotationRequest request
)

Enables the managed rotation feature for a Secret. This method can only be triggered once for a secret. In order to do further rotations, RotateSecret should be used. This method will add a secret version and update the password in Cloud SQL.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<SecretVersion> enableManagedRotation(
  EnableManagedRotationRequest request,
) async {
  final url = _endPoint.replace(
    path: '/v1/${request.parent}:enableManagedRotation',
  );
  final response = await _client.post(url, body: request);
  return SecretVersion.fromJson(response);
}