SecretVersion class final

A secret version resource in the Secret Manager API.

Constructors

SecretVersion({String name = '', Timestamp? createTime, Timestamp? destroyTime, SecretVersion_State state = SecretVersion_State.$default, ReplicationStatus? replicationStatus, String etag = '', bool clientSpecifiedPayloadChecksum = false, Timestamp? scheduledDestroyTime, CustomerManagedEncryptionStatus? customerManagedEncryption})
SecretVersion.fromJson(Object? j)
factory

Properties

clientSpecifiedPayloadChecksum → bool
Output only. True if payload checksum specified in SecretPayload object has been received by SecretManagerService on SecretManagerService.AddSecretVersion.
final
createTime → Timestamp?
Output only. The time at which the SecretVersion was created.
final
customerManagedEncryption → CustomerManagedEncryptionStatus?
Output only. The customer-managed encryption status of the SecretVersion. Only populated if customer-managed encryption is used and Secret is a regionalized secret.
final
destroyTime → Timestamp?
Output only. The time this SecretVersion was destroyed. Only present if state is DESTROYED.
final
etag → String
Output only. Etag of the currently stored SecretVersion.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Output only. The resource name of the SecretVersion in the format projects/*/secrets/*/versions/*.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
replicationStatus → ReplicationStatus?
The replication status of the SecretVersion.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledDestroyTime → Timestamp?
Optional. Output only. Scheduled destroy time for secret version. This is a part of the Delayed secret version destroy feature. For a Secret with a valid version destroy TTL, when a secert version is destroyed, version is moved to disabled state and it is scheduled for destruction Version is destroyed only after the scheduled_destroy_time.
final
state → SecretVersion_State
Output only. The current state of the SecretVersion.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String