SecretVersion_State class final

The state of a SecretVersion, indicating if it can be accessed.

Constructors

SecretVersion_State(String value)
const
SecretVersion_State.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const SecretVersion_State
The default value for SecretVersion_State.
destroyed → const SecretVersion_State
The SecretVersion is destroyed and the secret data is no longer stored. A version may not leave this state once entered.
disabled → const SecretVersion_State
The SecretVersion may not be accessed, but the secret data is still available and can be placed back into the ENABLED state.
enabled → const SecretVersion_State
The SecretVersion may be accessed.
stateUnspecified → const SecretVersion_State
Not specified. This value is unused and invalid.