destroyed constant

SecretVersion_State const destroyed

The SecretVersion is destroyed and the secret data is no longer stored. A version may not leave this state once entered.

Implementation

static const destroyed = SecretVersion_State('DESTROYED');