disabled constant

SecretVersion_State const disabled

The SecretVersion may not be accessed, but the secret data is still available and can be placed back into the ENABLED state.

Implementation

static const disabled = SecretVersion_State('DISABLED');