FakeSecretManagerService class base

Testing fake for SecretManagerService.

Implemented types

Constructors

FakeSecretManagerService({Future<ListSecretsResponse> listSecrets(ListSecretsRequest request)?, Future<Secret> createSecret(CreateSecretRequest request)?, Future<SecretVersion> addSecretVersion(AddSecretVersionRequest request)?, Future<Secret> getSecret(GetSecretRequest request)?, Future<Secret> updateSecret(UpdateSecretRequest request)?, Future<void> deleteSecret(DeleteSecretRequest request)?, Future<ListSecretVersionsResponse> listSecretVersions(ListSecretVersionsRequest request)?, Future<SecretVersion> getSecretVersion(GetSecretVersionRequest request)?, Future<AccessSecretVersionResponse> accessSecretVersion(AccessSecretVersionRequest request)?, Future<SecretVersion> disableSecretVersion(DisableSecretVersionRequest request)?, Future<SecretVersion> enableSecretVersion(EnableSecretVersionRequest request)?, Future<SecretVersion> destroySecretVersion(DestroySecretVersionRequest request)?, Future<Policy> setIamPolicy(SetIamPolicyRequest request)?, Future<Policy> getIamPolicy(GetIamPolicyRequest request)?, Future<TestIamPermissionsResponse> testIamPermissions(TestIamPermissionsRequest request)?, Future<ListLocationsResponse> listLocations(ListLocationsRequest request)?, Future<Location> getLocation(GetLocationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accessSecretVersion(AccessSecretVersionRequest request) Future<AccessSecretVersionResponse>
Accesses a SecretVersion. This call returns the secret data.
override
addSecretVersion(AddSecretVersionRequest request) Future<SecretVersion>
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
createSecret(CreateSecretRequest request) Future<Secret>
Creates a new Secret containing no SecretVersions.
override
deleteSecret(DeleteSecretRequest request) Future<void>
Deletes a Secret.
override
destroySecretVersion(DestroySecretVersionRequest request) Future<SecretVersion>
Destroys a SecretVersion.
override
disableSecretVersion(DisableSecretVersionRequest request) Future<SecretVersion>
Disables a SecretVersion.
override
enableSecretVersion(EnableSecretVersionRequest request) Future<SecretVersion>
Enables a SecretVersion.
override
getIamPolicy(GetIamPolicyRequest request) Future<Policy>
Gets the access control policy for a secret. Returns empty policy if the secret exists and does not have a policy set.
override
getLocation(GetLocationRequest request) Future<Location>
Gets information about a location.
override
getSecret(GetSecretRequest request) Future<Secret>
Gets metadata for a given Secret.
override
getSecretVersion(GetSecretVersionRequest request) Future<SecretVersion>
Gets metadata for a SecretVersion.
override
listLocations(ListLocationsRequest request) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
override
listSecrets(ListSecretsRequest request) Future<ListSecretsResponse>
Lists Secrets.
override
listSecretVersions(ListSecretVersionsRequest request) Future<ListSecretVersionsResponse>
Lists SecretVersions. This call does not return secret data.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(SetIamPolicyRequest request) Future<Policy>
Sets the access control policy on the specified secret. Replaces any existing policy.
override
testIamPermissions(TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
Returns permissions that a caller has for the specified secret. If the secret does not exist, this call returns an empty set of permissions, not a NOT_FOUND error.
override
toString() String
A string representation of this object.
inherited
updateSecret(UpdateSecretRequest request) Future<Secret>
Updates metadata of an existing Secret.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited