addSecretVersion method

  1. @override
Future<SecretVersion> addSecretVersion(
  1. AddSecretVersionRequest request
)
override

Creates a new SecretVersion containing secret data and attaches it to an existing Secret.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<SecretVersion> addSecretVersion(
  AddSecretVersionRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_addSecretVersion case final addSecretVersion?) {
    return addSecretVersion(request);
  }
  throw UnsupportedError('addSecretVersion');
}