secretmanager library
The Google Cloud client for the Secret Manager API.
Stores sensitive data such as API keys, passwords, and certificates. Provides convenience while improving security.
Classes
- AccessSecretVersionRequest
-
Request message for
SecretManagerService.AccessSecretVersion. - AccessSecretVersionResponse
-
Response message for
SecretManagerService.AccessSecretVersion. - AddSecretVersionRequest
-
Request message for
SecretManagerService.AddSecretVersion. - CreateSecretRequest
-
Request message for
SecretManagerService.CreateSecret. - CustomerManagedEncryption
- Configuration for encrypting secret payloads using customer-managed encryption keys (CMEK).
- CustomerManagedEncryptionStatus
- Describes the status of customer-managed encryption.
- DeleteSecretRequest
-
Request message for
SecretManagerService.DeleteSecret. - DestroySecretVersionRequest
-
Request message for
SecretManagerService.DestroySecretVersion. - DisableSecretVersionRequest
-
Request message for
SecretManagerService.DisableSecretVersion. - EnableManagedRotationRequest
-
Request message for
SecretManagerService.EnableManagedRotation. - EnableManagedRotationRequest_CloudSqlsingleUserCredentials
- These are the credentials required for Cloud SQL DB for Single user Managed Rotation.
- EnableSecretVersionRequest
-
Request message for
SecretManagerService.EnableSecretVersion. - GetSecretRequest
-
Request message for
SecretManagerService.GetSecret. - GetSecretVersionRequest
-
Request message for
SecretManagerService.GetSecretVersion. - ListSecretsRequest
-
Request message for
SecretManagerService.ListSecrets. - ListSecretsResponse
-
Response message for
SecretManagerService.ListSecrets. - ListSecretVersionsRequest
-
Request message for
SecretManagerService.ListSecretVersions. - ListSecretVersionsResponse
-
Response message for
SecretManagerService.ListSecretVersions. - Replication
- A policy that defines the replication and encryption configuration of data.
- Replication_Automatic
-
A replication policy that replicates the
Secretpayload without any restrictions. - Replication_UserManaged
-
A replication policy that replicates the
Secretpayload into the locations specified inReplication.UserManaged.replicas - Replication_UserManaged_Replica
-
Represents a Replica for this
Secret. - ReplicationStatus
-
The replication status of a
SecretVersion. - ReplicationStatus_AutomaticStatus
-
The replication status of a
SecretVersionusing automatic replication. - ReplicationStatus_UserManagedStatus
-
The replication status of a
SecretVersionusing user-managed replication. - ReplicationStatus_UserManagedStatus_ReplicaStatus
-
Describes the status of a user-managed replica for the
SecretVersion. - RotateSecretRequest
-
Request message for
SecretManagerService.RotateSecret. - Rotation
-
The rotation time and period for a
Secret. At next_rotation_time, Secret Manager will send a Pub/Sub notification to the topics configured on the Secret.Secret.topicsmust be set to configure rotation. - Rotation_ManagedRotationStatus
- Represents the status of a managed rotation.
- Rotation_ManagedRotationStatus_State
- This defines the various states in which the managed rotation can be.
- Secret
-
A
Secretis a logical secret whose value and versions can be accessed. - Secret_SecretType
- This defines the various values of the type of secret can be.
- SecretManagerService
- Secret Manager Service
- SecretPayload
-
A secret payload resource in the Secret Manager API. This contains the
sensitive secret payload that is associated with a
SecretVersion. - SecretVersion
- A secret version resource in the Secret Manager API.
- SecretVersion_State
-
The state of a
SecretVersion, indicating if it can be accessed. - Topic
- A Pub/Sub topic which Secret Manager will publish to when control plane events occur on this secret.
- UpdateSecretRequest
-
Request message for
SecretManagerService.UpdateSecret.
Exceptions / Errors
- BadGatewayException
- Exception thrown when the server returns a "502 Bad Gateway" response.
- BadRequestException
- Exception thrown when the server returns a "400 Bad Request" response.
- CancelledException
- Exception thrown when the server returns a "499 Cancelled" response.
- ConfigurationException
- Exception thrown when a method is called without correct configuration.
- ConflictException
- Exception thrown when the server returns a "409 Conflict" response.
- ForbiddenException
- Exception thrown when the server returns a "403 Forbidden" response.
- GatewayTimeoutException
- Exception thrown when the server returns a "504 Gateway Timeout" response.
- InternalServerErrorException
- Exception thrown when the server returns a "500 Internal Server Error" response.
- LengthRequiredException
- Exception thrown when the server returns a "411 Length Required" response.
- MethodNotAllowedException
- Exception thrown when the server returns a "405 Method Not Allowed" response.
- NotFoundException
- Exception thrown when the server returns a "404 Not Found" response.
- NotImplementedException
- Exception thrown when the server returns a "501 Not Implemented" response.
- NotModifiedException
- Exception thrown when the server returns a "304 Not Modified" response.
- PreconditionFailedException
- Exception thrown when the server returns a "412 Precondition Failed" response.
- RequestRangeNotSatisfiableException
- Exception thrown when the server returns a "416 Request Range Not Satisfiable" response.
- RequestTimeoutException
- Exception thrown when the server returns a "408 Request Timeout" response.
- ServiceException
- Exception thrown when an API call fails.
- Exception thrown when the server returns a "503 Service Unavailable" response.
- TooManyRequestsException
- Exception thrown when the server returns a "429 Too Many Requests" response.
- Exception thrown when the server returns a "401 Unauthorized" response.