EnableManagedRotationRequest class final
Request message for
SecretManagerService.EnableManagedRotation.
Constructors
- EnableManagedRotationRequest({required String parent, EnableManagedRotationRequest_CloudSqlsingleUserCredentials? cloudSqlSingleUserCredentials})
- EnableManagedRotationRequest.fromJson(Object? j)
-
factory
Properties
- cloudSqlSingleUserCredentials → EnableManagedRotationRequest_CloudSqlsingleUserCredentials?
-
Credentials required for Cloud SQL DB for Single user Managed Rotation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent → String
-
Required. The resource name of the
Secretto associate with theSecretVersionin the formatprojects/*/secrets/*orprojects/*/locations/*/secrets/*.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String