versionAliases property
Optional. Mapping from version alias to version name.
A version alias is a string with a maximum length of 63 characters and can
contain uppercase and lowercase letters, numerals, and the hyphen (-)
and underscore ('_') characters. An alias string must start with a
letter and cannot be the string 'latest' or 'NEW'.
No more than 50 aliases can be assigned to a given secret.
Version-Alias pairs will be viewable via GetSecret and modifiable via UpdateSecret. Access by alias is only be supported on GetSecretVersion and AccessSecretVersion.
Implementation
final Map<String, int> versionAliases;