scheduledDestroyTime property
Timestamp?
scheduledDestroyTime
final
Optional. Output only. Scheduled destroy time for secret version. This is a part of the Delayed secret version destroy feature. For a Secret with a valid version destroy TTL, when a secert version is destroyed, version is moved to disabled state and it is scheduled for destruction Version is destroyed only after the scheduled_destroy_time.
Implementation
final Timestamp? scheduledDestroyTime;